import logging
from typing import Any

import configargparse


def get_config() -> Any:
    global config
    parser = configargparse.get_argument_parser(
        config_file_parser_class=configargparse.YAMLConfigFileParser,
        formatter_class=configargparse.ArgumentDefaultsHelpFormatter,
    )
    parser.add_argument(
        "-c", "--config", required=False, is_config_file=True, help="config file path"
    )
    parser.add_argument(
        "--local", required=False, is_config_file=True, help="local config file path"
    )
    parser.add_argument(
        "--config-save",
        required=False,
        is_write_out_config_file_arg=True,
        help="config file path",
    )
    
    parser.add_argument("files", nargs="*", default=[], help="list of documents")
    parser.add_argument("--debug", action="store_true", default=False, help="debug")
    parser.add_argument("--dry-run", action="store_true", default=False, help="Check only")
    parser.add_argument("--task", default="report", choices=["upload", "report", "evaluate", "convert"], help="Desidered operation")
    parser.add_argument("--model", default="gemini-2.0-flash-lite-001", help="model")
    parser.add_argument("--person", action="append", default=["Federico Bricolo", "Maurizio Danese"], help="list of documents")
    parser.add_argument("--env", choices=["development", "production"], default="development", help="Running mode(development o production)")
    parser.add_argument("-e", "--extension", action="append", help="list of documents")
    parser.add_argument("-t", "--token", default="", help="list of documents")

    config, _ = parser.parse_known_args()
    if config.debug:
        import jurigged

        logging.getLogger("watchdog").setLevel(logging.INFO)
        jurigged.watch(pattern="*gtagger*.py")

    logging.basicConfig(
        format="%(asctime)s [%(levelname)s] %(name)s %(message)s",
        level=logging.DEBUG if config.debug else logging.INFO,
    )

    # Normalizzo la lista estensioni
    DEFAULT_EXT=[".pdf", ".odt", ".txt", ".pptx", ".doc", ".xlsx", ".docx"]
    extensions = (
        [ext if ext.startswith('.') else f'.{ext}' for ext in config.extension]
        # Usa il Default se l'utente non ha fornitas almeno una
        if config.extension 
        else DEFAULT_EXT
    )
    
    config.extension = extensions

    return config

config = get_config()

